=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2008-12-20 23:44:07 +0000
+++ drizzled/Makefile.am	2008-12-21 00:17:47 +0000
@@ -294,6 +294,7 @@
 		probes.h \
 		protocol.h \
 		qcache.h \
+		query_arena.h \
 		query_id.h \
 		rename.h \
 		replication/binlog.h \

=== modified file 'drizzled/my_decimal.h'
--- drizzled/my_decimal.h	2008-12-06 19:42:46 +0000
+++ drizzled/my_decimal.h	2008-12-21 00:17:47 +0000
@@ -291,7 +291,6 @@
 int str2my_decimal(uint32_t mask, const char *from, uint32_t length,
                    const CHARSET_INFO * charset, my_decimal *decimal_value);
 
-#if defined(DRIZZLE_SERVER)
 inline
 int string2my_decimal(uint32_t mask, const String *str, my_decimal *d)
 {
@@ -302,8 +301,6 @@
 my_decimal *date2my_decimal(DRIZZLE_TIME *ltime, my_decimal *dec);
 
 
-#endif /*defined(DRIZZLE_SERVER) */
-
 inline
 int double2my_decimal(uint32_t mask, double val, my_decimal *d)
 {

=== added file 'drizzled/query_arena.h'
--- drizzled/query_arena.h	1970-01-01 00:00:00 +0000
+++ drizzled/query_arena.h	2008-12-21 00:17:47 +0000
@@ -0,0 +1,76 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#ifndef DRIZZLED_QUERY_ARENA_H
+#define DRIZZLED_QUERY_ARENA_H
+
+#include <drizzled/global.h>
+#include <mysys/my_alloc.h>
+
+class Item;
+
+class Query_arena
+{
+public:
+  /*
+    List of items created in the parser for this query. Every item puts
+    itself to the list on creation (see Item::Item() for details))
+  */
+  Item *free_list;
+  MEM_ROOT *mem_root;                   // Pointer to current memroot
+
+  Query_arena(MEM_ROOT *mem_root_arg) :
+    free_list(0), mem_root(mem_root_arg)
+  { }
+  /*
+    This constructor is used only when Query_arena is created as
+    backup storage for another instance of Query_arena.
+  */
+  Query_arena() { }
+
+  virtual ~Query_arena() {};
+
+  inline void* alloc(size_t size) { return alloc_root(mem_root,size); }
+  inline void* calloc(size_t size)
+  {
+    void *ptr;
+    if ((ptr=alloc_root(mem_root,size)))
+      memset(ptr, 0, size);
+    return ptr;
+  }
+  inline char *strdup(const char *str)
+  { return strdup_root(mem_root,str); }
+  inline char *strmake(const char *str, size_t size)
+  { return strmake_root(mem_root,str,size); }
+  inline void *memdup(const void *str, size_t size)
+  { return memdup_root(mem_root,str,size); }
+  inline void *memdup_w_gap(const void *str, size_t size, uint32_t gap)
+  {
+    void *ptr;
+    if ((ptr= alloc_root(mem_root,size+gap)))
+      memcpy(ptr,str,size);
+    return ptr;
+  }
+
+  void free_items();
+};
+
+
+#endif /* DRIZZLED_QUERY_ARENA_H */

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2008-12-18 07:24:54 +0000
+++ drizzled/session.h	2008-12-21 00:17:47 +0000
@@ -35,6 +35,7 @@
 #include <drizzled/handler.h>
 #include <drizzled/current_session.h>
 #include <drizzled/sql_error.h>
+#include <drizzled/query_arena.h>
 #include <string>
 #include <bitset>
 
@@ -332,53 +333,6 @@
 
 #ifdef DRIZZLE_SERVER
 
-class Query_arena
-{
-public:
-  /*
-    List of items created in the parser for this query. Every item puts
-    itself to the list on creation (see Item::Item() for details))
-  */
-  Item *free_list;
-  MEM_ROOT *mem_root;                   // Pointer to current memroot
-
-  Query_arena(MEM_ROOT *mem_root_arg) :
-    free_list(0), mem_root(mem_root_arg)
-  { }
-  /*
-    This constructor is used only when Query_arena is created as
-    backup storage for another instance of Query_arena.
-  */
-  Query_arena() { }
-
-  virtual ~Query_arena() {};
-
-  inline void* alloc(size_t size) { return alloc_root(mem_root,size); }
-  inline void* calloc(size_t size)
-  {
-    void *ptr;
-    if ((ptr=alloc_root(mem_root,size)))
-      memset(ptr, 0, size);
-    return ptr;
-  }
-  inline char *strdup(const char *str)
-  { return strdup_root(mem_root,str); }
-  inline char *strmake(const char *str, size_t size)
-  { return strmake_root(mem_root,str,size); }
-  inline void *memdup(const void *str, size_t size)
-  { return memdup_root(mem_root,str,size); }
-  inline void *memdup_w_gap(const void *str, size_t size, uint32_t gap)
-  {
-    void *ptr;
-    if ((ptr= alloc_root(mem_root,size+gap)))
-      memcpy(ptr,str,size);
-    return ptr;
-  }
-
-  void free_items();
-};
-
-
 /**
   @class Statement
   @brief State of a single command executed against this connection.

